@@ -121,15 +121,18 @@ def load_config_common() -> ConfigCommon:
         # Provide default values for namespace and tag
         if common_section.get(NAMESPACE, None) is None:
             common_section[NAMESPACE] = "default"
-            print_log(
-                "Using default value for 'namespace': " f"'{common_section[NAMESPACE]}'"
-            )
+            if ARGS_PARSER.namespace_required:
+                print_log(
+                    "Using default value for 'namespace': "
+                    f"'{common_section[NAMESPACE]}'"
+                )
         if common_section.get(NAME_TAG, None) is None:
             common_section[NAME_TAG] = "{{username}}"
-            print_log(
-                "Using default value for 'tag/prefix/name' = "
-                f"'{VARIABLE_SUBSTITUTIONS['username']}'"
-            )
+            if ARGS_PARSER.tag_required:
+                print_log(
+                    "Using default value for 'tag/prefix/name' = "
+                    f"'{VARIABLE_SUBSTITUTIONS['username']}'"
+                )
 
         url = process_variable_substitutions(common_section.get(URL, DEFAULT_URL))
         if url != DEFAULT_URL:
@@ -302,6 +305,7 @@ def load_config_work_requirement() -> ConfigWorkRequirement:
             task_count=task_count,
             task_data=wr_section.get(TASK_DATA, None),
             task_data_file=wr_section.get(TASK_DATA_FILE, None),
+            task_group_count=wr_section.get(TASK_GROUP_COUNT, 1),
             task_group_name=wr_section.get(TASK_GROUP_NAME, None),
             task_name=wr_section.get(TASK_NAME, None),
             task_timeout=wr_section.get(TASK_TIMEOUT, None),
