@@ -55,6 +55,7 @@ HIGHLIGHTED_STATES = [
     r"(?P<active>RUNNING)",
     r"(?P<active>TARGET)",
     r"(?P<active>ALIVE)",
+    r"(?P<active>MATCHING)",
     r"(?P<cancelled>ABORTED)",
     r"(?P<cancelled>CANCELLED)",
     r"(?P<cancelled>CANCELLING)",
@@ -66,6 +67,7 @@ HIGHLIGHTED_STATES = [
     r"(?P<failed>FAILED)",
     r"(?P<failed>FAILING)",
     r"(?P<failed>LOST)",
+    r"(?P<failed>NON-MATCHING)",
     r"(?P<idle>EMPTY)",
     r"(?P<idle>FOUND)",
     r"(?P<idle>IDLE)",
